@@ -4,8 +4,6 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.009;
-
 use Prty::Object;
 use Time::HiRes ();
 use Prty::Option;
@@ -18,7 +16,7 @@ use Prty::ColumnFormat;
 
 =head1 NAME
 
-Prty::Database::ResultSet - Liste von Datensätzen (abstrakt)
+Prty::Database::ResultSet - Liste von Datensätzen (abstrakte Basisklasse)
 
 =head1 BASE CLASS
 
@@ -886,23 +884,10 @@ sub diffReport {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
