@@ -4,8 +4,6 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.009;
-
 # -----------------------------------------------------------------------------
 
 =encoding utf8
@@ -21,13 +19,15 @@ L<Prty::Object>
 =head1 DESCRIPTION
 
 Ein Objekt der Klasse repräsentiert eine Zeitdauer, die intern als
-numerischer Wert (Sekunden mit Nachkommastellen) gespeichert wird.
+numerischer Wert gespeichert wird. Der Wert ist die Anzahl Sekunden,
+ggf. mit Nachkommastellen.
 
-Als externe Repäsentation wird die Darstellung
+Als weitere (externe) Repäsentation gibt es eine Darstellung als
+Zeichenkette in der Form
 
     DdHhMmS.Xs
 
-verwendet, wobei
+wobei
 
     D = Anzahl Tage
     H = Anzahl Stunden
@@ -75,8 +75,8 @@ der Sekundenanteil kann Nachkommastellen haben
 =head4 Description
 
 Instanziiere ein Zeitdauer-Objekt und liefere einen Referenz auf
-dieses Objekt zurück. Die Zeitdauer kann als numerischer Wert $sec
-oder als Zeichenkette $str angegeben werden.
+dieses Objekt zurück. Die Zeitdauer kann als numerischer Wert
+oder als Zeichenkette angegeben werden.
 
 =cut
 
@@ -179,6 +179,21 @@ sub asArray {
 
     $str = $dur->asFFmpegString;
 
+=head4 Arguments
+
+=over 4
+
+=item $sec
+
+Anzahl Sekunden, ggf. mit Nachkommastellen.
+
+=item $prec (Default: 0)
+
+Anzahl der Nachkommastellen bei den Sekunden. Ist kein Wert angegeben,
+wird auf ganze Sekunden gerundet.
+
+=back
+
 =head4 Description
 
 Liefere Dauer in der Form wie sie ffmpeg bei der Option -t erwartet,
@@ -364,23 +379,10 @@ sub secondsToString {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
