@@ -4,8 +4,6 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.009;
-
 use Prty::Shell;
 use Prty::File::Image;
 use Prty::Path;
@@ -16,7 +14,7 @@ use Prty::Path;
 
 =head1 NAME
 
-Prty::ImageMagick - Konstruiere eine ImageMagick-Kommandozeile
+Prty::ImageMagick - ImageMagick-Kommandozeile
 
 =head1 BASE CLASS
 
@@ -27,13 +25,12 @@ L<Prty::Hash>
 ImageMagick Online-Dokumentation:
 L<http://www.imagemagick.org/Usage/>
 
-Ein Objekt der Klasse repräsentiert eine
-ImageMagick-Kommandozeile.  Die Klasse verfügt einerseits über
-I<elementare> (Objekt-)Methoden, um eine solche Kommandozeile
-sukzessive aus ihren elementaren Bestandteilen konstruieren zu
-können und I<höhere> (Klassen-)Methoden, die eine bestimmte
-Funktion durch das Hinzufügen einer Reihe von Optionen
-realisieren.
+Ein Objekt der Klasse repräsentiert eine ImageMagick-Kommandozeile.
+Die Klasse verfügt einerseits über I<elementare> Objektmethoden,
+um eine solche Kommandozeile sukzessive aus ihren elementaren
+Bestandteilen konstruieren zu können und I<höhere> Objektmethoden, die
+eine bestimmte Funktion durch das Hinzufügen einer Reihe von
+Optionen realisieren.
 
 =head1 METHODS
 
@@ -525,23 +522,10 @@ sub morph {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
