@@ -5,8 +5,6 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.009;
-
 use Prty::OrderedHash;
 use Prty::FileHandle;
 
@@ -406,23 +404,10 @@ sub images {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
