@@ -4,8 +4,6 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.009;
-
 use Prty::Option;
 use Prty::Shell;
 use IPC::Open3 ();
@@ -99,23 +97,10 @@ sub filter {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
