@@ -3,8 +3,6 @@ package Prty::Stacktrace;
 use strict;
 use warnings;
 
-our $VERSION = 1.009;
-
 # -----------------------------------------------------------------------------
 
 =encoding utf8
@@ -187,23 +185,10 @@ sub asString {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
