@@ -4,8 +4,6 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.009;
-
 use Storable ();
 
 # -----------------------------------------------------------------------------
@@ -69,6 +67,10 @@ sub freeze {
 
     $ref = Prty::Storable->thaw($str);
 
+=head3 Returns
+
+Datenstruktur
+
 =cut
 
 # -----------------------------------------------------------------------------
@@ -81,23 +83,10 @@ sub thaw {
 
 # -----------------------------------------------------------------------------
 
-=head1 VERSION
-
-1.009
-
 =head1 AUTHOR
 
 Frank Seitz, L<http://fseitz.de/>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2016 Frank Seitz
-
-=head1 LICENSE
-
-This code is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =cut
 
 # -----------------------------------------------------------------------------
